@@ -1,5 +1,6 @@
 from .dione import Dione
 from .europa import Europa 
 from .callisto import Callisto
+from .neso import Neso 
 
-__all__ = ['Europa', 'Dione', 'Callisto']
\ No newline at end of file
+__all__ = ['Europa', 'Dione', 'Callisto', 'Neso']
\ No newline at end of file
